Introduction
============
A portlet that extends the base Static Portlet of Plone and add some new fields and features.

Dependencies
============

1.x branch: Plone 3 and 4
2.x (master): Plone 5


Set a background image
----------------------

In portlet's configuration there are two fields that allows to add an image background in portlet header. The image will be set as a "background-image" style in the header of the portlet.

You can also set the height or leave the default one.

Internal link field
-------------------

There is a new field that allows to set an internal link to show in "more" link. If this field is set, it overrides base external link of static portlet.

Custom CSS class field
-----------------------
You can assign some custom css classes to the portlet.

Preset Style Classes
--------------------
In the portlet configuration there is a field that allows to choose a style class from a preset list.

You can edit the list of styles in resource registry (@@portal_registry) entry: rer.portlet.advanced_static.css_styles.

Credits
=======

Developed with the support of `Regione Emilia Romagna`__; Regione Emilia Romagna supports the `PloneGov initiative`__.

__ http://www.regione.emilia-romagna.it/
__ http://www.plonegov.it/

Authors
=======

This product was developed by RedTurtle Technology team.

.. image:: http://www.redturtle.net/redturtle_banner.png
   :alt: RedTurtle Technology Site
   :target: http://www.redturtle.net/
